@@ -2,15 +2,16 @@ import itertools
 import queue
 import time
 import weakref
-from typing import List, Any, Tuple, Optional, Callable, Union, Match, AnyStr, Generator
+from typing import List, Any, Tuple, Optional, Callable, Union, Match, AnyStr, Generator, Dict
 from xmlrpc.client import ResponseError
 
 import redis
 from redis.connection import DefaultParser
 
+from fakeredis.model import XStream, ZSet, Hash, ExpiringMembersSet
 from . import _msgs as msgs
 from ._command_args_parsing import extract_args
-from ._commands import Int, Float, SUPPORTED_COMMANDS, COMMANDS_WITH_SUB, Signature, CommandItem, Hash
+from ._commands import Int, Float, SUPPORTED_COMMANDS, COMMANDS_WITH_SUB, Signature, CommandItem
 from ._helpers import (
     SimpleError,
     valid_response_type,
@@ -21,8 +22,6 @@ from ._helpers import (
     QUEUED,
     decode_command_bytes,
 )
-from ._stream import XStream
-from ._zset import ZSet
 
 
 def _extract_command(fields: List[bytes]) -> Tuple[Any, List[Any]]:
@@ -63,7 +62,6 @@ class BaseFakeSocket:
         "unsubscribe",
         "psubscribe",
         "punsubscribe",
-        "quit",
         "ssubscribe",
         "sunsubscribe",
     }
@@ -88,6 +86,20 @@ class BaseFakeSocket:
         self._in_transaction: bool
         self._pubsub: int
         self._transaction_failed: bool
+        info = kwargs.pop("client_info", dict(user="default"))
+        self._client_info: Dict[str, Union[str, int]] = {k.replace("_", "-"): v for k, v in info.items()}
+
+    @property
+    def client_info(self) -> bytes:
+        return " ".join([f"{k}={v}" for k, v in self._client_info.items()]).encode()
+
+    @property
+    def current_user(self) -> bytes:
+        return self._client_info.get("user", "").encode()
+
+    @property
+    def protocol_version(self) -> int:
+        return self._client_info.get("resp", 2)
 
     @property
     def version(self) -> Tuple[int, ...]:
@@ -183,6 +195,49 @@ class BaseFakeSocket:
                 buf = buf[length + 2 :]  # +2 to skip the CRLF
             self._process_command(fields)
 
+    def _process_command(self, fields: List[bytes]) -> None:
+        if not fields:
+            return
+        result: Any
+        cmd, cmd_arguments = _extract_command(fields)
+        try:
+            func, sig = self._name_to_func(cmd)
+            self._server.acl.validate_command(self.current_user, self.client_info, fields)  # ACL check
+            with self._server.lock:
+                # Clean out old connections
+                while True:
+                    try:
+                        weak_sock = self._server.closed_sockets.pop()
+                    except IndexError:
+                        break
+                    else:
+                        sock = weak_sock()
+                        if sock:
+                            sock._cleanup(self._server)
+                now = time.time()
+                for db in self._server.dbs.values():
+                    db.time = now
+                sig.check_arity(cmd_arguments, self.version)
+                if self._transaction is not None and msgs.FLAG_TRANSACTION not in sig.flags:
+                    self._transaction.append((func, sig, cmd_arguments))
+                    result = QUEUED
+                else:
+                    result = self._run_command(func, sig, cmd_arguments, False)
+        except SimpleError as exc:
+            if self._transaction is not None:
+                # TODO: should not apply if the exception is from _run_command
+                # e.g. watch inside multi
+                self._transaction_failed = True
+            if cmd == "exec" and exc.value.startswith("ERR "):
+                exc.value = "EXECABORT Transaction discarded because of: " + exc.value[4:]
+                self._transaction = None
+                self._transaction_failed = False
+                self._clear_watches()
+            result = exc
+        result = self._decode_result(result)
+        if not isinstance(result, NoResponse):
+            self.put_response(result)
+
     def _run_command(
         self, func: Optional[Callable[[Any], Any]], sig: Signature, args: List[Any], from_script: bool
     ) -> Any:
@@ -251,6 +306,10 @@ class BaseFakeSocket:
             clean_name = cmd_name.replace("\r", " ").replace("\n", " ")
             raise SimpleError(msgs.UNKNOWN_COMMAND_MSG.format(clean_name))
         sig = SUPPORTED_COMMANDS[cmd_name]
+        if self._server.server_type not in sig.server_types:
+            # redis remaps \r or \n in an error to ' ' to make it legal protocol
+            clean_name = cmd_name.replace("\r", " ").replace("\n", " ")
+            raise SimpleError(msgs.UNKNOWN_COMMAND_MSG.format(clean_name))
         func = getattr(self, sig.func_name, None)
         return func, sig
 
@@ -261,48 +320,6 @@ class BaseFakeSocket:
             data = data.encode("ascii")  # type: ignore
         self._parser.send(data)
 
-    def _process_command(self, fields: List[bytes]) -> None:
-        if not fields:
-            return
-        result: Any
-        cmd, cmd_arguments = _extract_command(fields)
-        try:
-            func, sig = self._name_to_func(cmd)
-            with self._server.lock:
-                # Clean out old connections
-                while True:
-                    try:
-                        weak_sock = self._server.closed_sockets.pop()
-                    except IndexError:
-                        break
-                    else:
-                        sock = weak_sock()
-                        if sock:
-                            sock._cleanup(self._server)
-                now = time.time()
-                for db in self._server.dbs.values():
-                    db.time = now
-                sig.check_arity(cmd_arguments, self.version)
-                if self._transaction is not None and msgs.FLAG_TRANSACTION not in sig.flags:
-                    self._transaction.append((func, sig, cmd_arguments))
-                    result = QUEUED
-                else:
-                    result = self._run_command(func, sig, cmd_arguments, False)
-        except SimpleError as exc:
-            if self._transaction is not None:
-                # TODO: should not apply if the exception is from _run_command
-                # e.g. watch inside multi
-                self._transaction_failed = True
-            if cmd == "exec" and exc.value.startswith("ERR "):
-                exc.value = "EXECABORT Transaction discarded because of: " + exc.value[4:]
-                self._transaction = None
-                self._transaction_failed = False
-                self._clear_watches()
-            result = exc
-        result = self._decode_result(result)
-        if not isinstance(result, NoResponse):
-            self.put_response(result)
-
     def _scan(self, keys, cursor, *args):
         """This is the basis of most of the ``scan`` methods.
 
@@ -389,7 +406,7 @@ class BaseFakeSocket:
             return SimpleString(b"string")
         elif isinstance(key.value, list):
             return SimpleString(b"list")
-        elif isinstance(key.value, set):
+        elif isinstance(key.value, ExpiringMembersSet):
             return SimpleString(b"set")
         elif isinstance(key.value, ZSet):
             return SimpleString(b"zset")
