@@ -372,7 +372,7 @@ class SortedSetCommandsMixin:
 
     @command((Key(ZSet), ScoreTest, ScoreTest))
     def zremrangebyscore(self, key, _min, _max):
-        items = key.value.irange_score(_min.lower_bound, _max.upper_bound)
+        items = key.value.irange_score(_min.lower_bound, _max.upper_bound, reverse=False)
         return self.zrem(key, *[item[1] for item in items])
 
     @command((Key(ZSet), Int, Int))
