@@ -5,7 +5,7 @@ import fakeredis._msgs as msgs
 from fakeredis._command_args_parsing import extract_args
 from fakeredis._commands import Key, command, CommandItem, Int
 from fakeredis._helpers import SimpleError, casematch, OK, current_time, Database, SimpleString
-from fakeredis._stream import XStream, StreamRangeTest, StreamGroup, StreamEntryKey
+from fakeredis.model import XStream, StreamRangeTest, StreamGroup, StreamEntryKey
 
 
 class StreamsCommandsMixin:
@@ -71,9 +71,12 @@ class StreamsCommandsMixin:
     @command(name="XREAD", fixed=(bytes,), repeat=(bytes,))
     def xread(self, *args: bytes) -> Optional[List[List[Union[bytes, List[Tuple[bytes, List[bytes]]]]]]]:
         (
-            count,
-            timeout,
-        ), left_args = extract_args(
+            (
+                count,
+                timeout,
+            ),
+            left_args,
+        ) = extract_args(
             args,
             (
                 "+count",
@@ -341,7 +344,7 @@ class StreamsCommandsMixin:
         res: List[Any] = list()
         for group, stream_name, start_id in group_params:
             stream_results = group.group_read(consumer_name, start_id, count, noack)
-            if first_pass and (count is None or len(stream_results) < count):
+            if first_pass and (count is None):
                 return None
             if len(stream_results) > 0 or start_id != b">":
                 res.append([stream_name, stream_results])
