@@ -1,4 +1,5 @@
 """Command mixin for emulating `redis-py`'s cuckoo filter functionality."""
+
 import io
 from typing import List, Any
 
@@ -11,7 +12,6 @@ from fakeredis._helpers import SimpleError, OK, casematch, SimpleString
 
 
 class ScalableCuckooFilter(CountingCuckooFilter):
-
     def __init__(self, capacity: int, bucket_size: int = 2, max_iterations: int = 20, expansion: int = 1):
         super().__init__(capacity, bucket_size, max_iterations, expansion)
         self.initial_capacity: int = capacity
@@ -37,7 +37,6 @@ class ScalableCuckooFilter(CountingCuckooFilter):
 
 
 class CFCommandsMixin:
-
     @staticmethod
     def _cf_add(key: CommandItem, item: bytes) -> int:
         if key.value is None:
@@ -78,26 +77,34 @@ class CFCommandsMixin:
     @command(name="CF.INFO", fixed=(Key(),), repeat=())
     def cf_info(self, key: CommandItem) -> List[Any]:
         if key.value is None or type(key.value) is not ScalableCuckooFilter:
-            raise SimpleError('...')
+            raise SimpleError("...")
         return [
-            b'Size', key.value.capacity,
-            b'Number of buckets', len(key.value.buckets),
-            b'Number of filters', (key.value.capacity / key.value.initial_capacity) / key.value.expansion_rate,
-            b'Number of items inserted', key.value.inserted,
-            b'Number of items deleted', key.value.deleted,
-            b'Bucket size', key.value.bucket_size,
-            b'Max iterations', key.value.max_swaps,
-            b'Expansion rate', key.value.expansion_rate,
+            b"Size",
+            key.value.capacity,
+            b"Number of buckets",
+            len(key.value.buckets),
+            b"Number of filters",
+            (key.value.capacity / key.value.initial_capacity) / key.value.expansion_rate,
+            b"Number of items inserted",
+            key.value.inserted,
+            b"Number of items deleted",
+            key.value.deleted,
+            b"Bucket size",
+            key.value.bucket_size,
+            b"Max iterations",
+            key.value.max_swaps,
+            b"Expansion rate",
+            key.value.expansion_rate,
         ]
 
     @command(name="CF.INSERT", fixed=(Key(),), repeat=(bytes,))
     def cf_insert(self, key: CommandItem, *args: bytes) -> List[int]:
         (capacity, no_create), left_args = extract_args(
-            args, ("+capacity", "nocreate"),
-            error_on_unexpected=False, left_from_first_unexpected=True)
+            args, ("+capacity", "nocreate"), error_on_unexpected=False, left_from_first_unexpected=True
+        )
         # if no_create and (capacity is not None or error_rate is not None):
         #     raise SimpleError("...")
-        if len(left_args) < 2 or not casematch(left_args[0], b'items'):
+        if len(left_args) < 2 or not casematch(left_args[0], b"items"):
             raise SimpleError("...")
         items = left_args[1:]
         capacity = capacity or 1024
@@ -115,11 +122,11 @@ class CFCommandsMixin:
     @command(name="CF.INSERTNX", fixed=(Key(),), repeat=(bytes,))
     def cf_insertnx(self, key: CommandItem, *args: bytes) -> List[int]:
         (capacity, no_create), left_args = extract_args(
-            args, ("+capacity", "nocreate"),
-            error_on_unexpected=False, left_from_first_unexpected=True)
+            args, ("+capacity", "nocreate"), error_on_unexpected=False, left_from_first_unexpected=True
+        )
         # if no_create and (capacity is not None or error_rate is not None):
         #     raise SimpleError("...")
-        if len(left_args) < 2 or not casematch(left_args[0], b'items'):
+        if len(left_args) < 2 or not casematch(left_args[0], b"items"):
             raise SimpleError("...")
         items = left_args[1:]
         capacity = capacity or 1024
@@ -143,12 +150,21 @@ class CFCommandsMixin:
             res.append(CFCommandsMixin._cf_exist(key, value))
         return res
 
-    @command(name="CF.RESERVE", fixed=(Key(), Int,), repeat=(bytes,), flags=msgs.FLAG_LEAVE_EMPTY_VAL)
+    @command(
+        name="CF.RESERVE",
+        fixed=(
+            Key(),
+            Int,
+        ),
+        repeat=(bytes,),
+        flags=msgs.FLAG_LEAVE_EMPTY_VAL,
+    )
     def cf_reserve(self, key: CommandItem, capacity: int, *args: bytes) -> SimpleString:
         if key.value is not None:
             raise SimpleError(msgs.ITEM_EXISTS_MSG)
         (bucket_size, max_iterations, expansion), _ = extract_args(
-            args, ("+bucketsize", "+maxiterations", "+expansion"))
+            args, ("+bucketsize", "+maxiterations", "+expansion")
+        )
 
         max_iterations = max_iterations or 20
         bucket_size = bucket_size or 2
@@ -156,7 +172,15 @@ class CFCommandsMixin:
         key.update(value)
         return OK
 
-    @command(name="CF.SCANDUMP", fixed=(Key(), Int,), repeat=(), flags=msgs.FLAG_LEAVE_EMPTY_VAL)
+    @command(
+        name="CF.SCANDUMP",
+        fixed=(
+            Key(),
+            Int,
+        ),
+        repeat=(),
+        flags=msgs.FLAG_LEAVE_EMPTY_VAL,
+    )
     def cf_scandump(self, key: CommandItem, iterator: int) -> List[Any]:
         if key.value is None:
             raise SimpleError(msgs.NOT_FOUND_MSG)
